'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = formatIncompletePhoneNumber;

var _AsYouType = require('./AsYouType');

var _AsYouType2 = _interopRequireDefault(_AsYouType);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Formats a (possibly incomplete) phone number.
 * The phone number can be either in E.164 format
 * or in a form of national number digits.
 * @param {string} value - A possibly incomplete phone number. Either in E.164 format or in a form of national number digits.
 * @param {string?} country - Two-letter ("ISO 3166-1 alpha-2") country code.
 * @return {object} `{ text : string, template : string }`. `text` is the formatted `value`. `template` is `text` where all characters of `value` are replaced with `x`-es.
 */
function formatIncompletePhoneNumber(value, country, metadata, options) {
	// "As you type" formatter.
	var formatter = new _AsYouType2.default(country, metadata);

	// Format the number.
	var number = formatter.input(value);

	// Return the formatting template if requested.
	if (options && options.template) {
		return { number: number, template: formatter.template };
	}

	return number;
}
//# sourceMappingURL=formatIncompletePhoneNumber.js.map